@@ -58,6 +58,27 @@ case "$1" in
             mkdir -p /etc/apache2/conf.d
             ln -sf /etc/benno-web/apache-2.2.conf /etc/apache2/conf.d/benno
         fi
+
+        # upgrade port settings
+        set +e
+        grep -q localhost:8080 /etc/benno-web/benno.conf 2>/dev/null
+        if [ $? -eq 0 ];then
+            perl -p -i -e 's/localhost:8080$/localhost:21080/' /etc/benno-web/benno.conf
+        else
+            BASEURL=`grep BASE_URL /etc/benno-web/benno.conf 2>/dev/null`
+            echo ""
+            echo ""
+            echo "################################################################"
+            echo "#  ACHTUNG! Bitte die Host- und Portkonfigurationen von"
+            echo "#    /etc/benno-web/benno.conf: ${BASEURL}"
+            echo "#  und"
+            echo "#    /etc/benno/jetty.xml: \"host\" und \"port\""
+            echo "#  vergleichen und gegebenenfalls anpassen."
+            echo "################################################################"
+        fi
+        set -e
+
+
     ;;
 
     abort-upgrade|abort-remove|abort-deconfigure)
