@@ -156,7 +156,7 @@ if (file_exists($SP_FILE)) {
     else {
         // authzError
         $App->log("ERR_AUTHZ $SP_FILE",1,'SPAF2');
-        $App->view = 'default';
+        $App->view = 'error';
     }
 }
 
@@ -184,7 +184,7 @@ if (file_exists($SP_FILE)) {
     else {
         // authzError
         $App->log("ERR_AUTHZ $SP_FILE",0,'SPAF2','SPAF2');
-        $App->view = 'default';
+        $App->view = 'error';
     }
 }
 
@@ -198,7 +198,7 @@ if (file_exists($MODULE.'/post_view.php')) {
 if ($App->getConfig('TEMPLATE_AUTHZ') &! $App->authz($App->view)) {
     // authzError
     $App->log("ERR_AUTHZ Template: $App->view.tpl",0,'SPAF2');
-    $App->view = 'default';
+    $App->view = 'error';
 }
 
 // set access level and curent view in template
