@@ -34,11 +34,10 @@
 // EMail from session (s.a. pre_ctrl)
 $filename    = $App->getParam('name');
 $contentType = $App->getParam('type');
-
-$bennoId = $EMail->bennoId;
+$sessionMailId = $App->getParam('id');
 
 try {
-    $attachmentData = $Backend->fetchAttachment($bennoId,$filename);
+    $attachmentData = $Backend->fetchAttachment($sessionMailId,$filename);
 
     header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
     header("Pragma: public");
