@@ -44,11 +44,9 @@ try {
     $QueryResult = $Backend->query($ExtQuery,0,$search_limit);
     if ($QueryResult->found == 0) {
         $App->setMsg('MSG_NOTFOUND');
+        $sessionMailId = '';
     }
     $sessionMailId = $QueryResult->getSessionMailId(0);
-    $EMail = $Backend->fetch($sessionMailId);       // show first mail
-    $displayedMailId = $sessionMailId;
-    $App->setSession('displayedMailId',$displayedMailId);
 
     // show extended Search
     $searchMaskState = 'Ext';
@@ -56,8 +54,13 @@ try {
     $App->assign('searchMaskState',$searchMaskState);
 }
 catch (Exception $e) {
-    $App->log('[searchQuery] '.$e->getMessage());
-    $App->setMsg($e->getMessage());
+    if ($e->getMessage() == 'ID_NOT_FOUND') {
+        $App->view = 'showList';
+    }
+    else {
+        $App->log($e->getMessage());
+        $App->setMsg($e->getMessage());
+    }
 }
 
 $App->view = 'showList';
