@@ -262,8 +262,14 @@ class Backend
         }
 
         if (($response = curl_exec($curl)) === false) {
-            $App->log('[Backend/query] Request error: '.curl_error($curl));
-            throw new Exception('ERR_REQUEST');
+            $errnum = curl_errno($curl);
+            $App->log('[Backend/query] Request error: '.curl_error($curl).'['.$errnum.']');
+            if ($errnum == 7) {
+                throw new Exception('ERR_REST_CON');
+            }
+            else {
+                throw new Exception('ERR_REQUEST');
+            }
         }
         $httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE); 
         if ($httpCode != 200) {
