@@ -107,13 +107,5 @@ class License
             }
         }
     }
-
-
-    function getError ()
-    {
-        global $App;
-        return $App->getMsg($this->status);
-    }
-
 }
 ?>
