@@ -68,7 +68,7 @@ class StoredQuery extends Persistence
         // check if query with this name exists
         global $App;
         $DB = $App->DB;
-        $sql = "SELECT * FROM storedquery WHERE name = '".$this->name."'";
+        $sql = "SELECT * FROM storedquery WHERE name = '".$this->name."' AND userid = '".$this->userid."'";
         $res = $DB->query($sql);
         if ($row = $res->fetchRow()) {
             throw new Exception('QUERY_NAME_EXISTS');
