@@ -63,9 +63,6 @@ else {
 }
 $App->assign('searchMaskState',$searchMaskState);
 
-// sessionMailId of current mail in content areay
-$displayedMailId = $App->getSession('displayedMailId');
-
 // fetch query field entries from session
 $searchmin   = $App->getSession('searchmin');
 $SimpleQuery = $App->getSession('SimpleQuery');
@@ -79,6 +76,9 @@ $timeslice = $App->getSession('timeslice');
 // sort messages (dateAsc dateDesc)
 $sortOrder = $App->getSession('sortOrder');
 
+// last mail shown
+$sessionMailId = $App->getSession('sessionMailId');
+
 // refresh last request time (session timeout)
 $lastRequestTime = $App->getSession('lastRequestTime'); // view/a_sessionRefresh
 $App->setSession('lastRequestTime',time());
