@@ -4,7 +4,7 @@ function authentication_required($message)
 {
     header('WWW-Authenticate: Basic realm="BENNOWEB REST API"');
     header('HTTP/1.0 401 Unauthorized');
-    print $message;
+    print $message."\n";
     exit;
 }
 
@@ -28,9 +28,12 @@ $rest_pass   = $App->getConfig('SHARED_SECRET');
 $base_url    = $App->getConfig('BASE_URL');
 $authscript  = $App->getConfig('EXTERNAL_AUTH');
 
-$userid  = $_SERVER['PHP_AUTH_USER'];
-$passwd  = $_SERVER['PHP_AUTH_PW'];
-$request = $_SERVER['PATH_INFO'];       // /search/ or /mail/
+$userid   = $_SERVER['PHP_AUTH_USER'];
+$passwd   = $_SERVER['PHP_AUTH_PW'];
+$req_self = $_SERVER['PHP_SELF'];      // /search/ or /mail/
+
+preg_match('/\/(\w+)\/?$/',$req_self,$matches);
+$rest_path = $matches[1];
 
 // Authentication
 if (! $passwd) {
@@ -70,11 +73,13 @@ $filterString = preg_replace('/\s/','%20',$filterString);
 
 $query_request = $_SERVER['QUERY_STRING'];
 $query_request = preg_replace('/[\&]?\bfilterQuery=[^\&]+/','',$query_request);
+$archives = $User->getArchives();
+$archive       = 'archive='.end($archives);
 $filterQuery   = 'filterQuery='.$filterString;
-$query_request = $query_request.'&'.$filterQuery;
+$query_request = $filterQuery.'&'.$archive.'&'.$query_request;
 
 // remove possible filter entries from query
-$url = $base_url.$_SERVER['PATH_INFO'].'?'.$query_request;
+$url = $base_url.'/'.$rest_path.'/?'.$query_request;
 
 // Open the cURL session
 $curl = curl_init();
@@ -90,7 +95,7 @@ if($_SERVER['REQUEST_METHOD'] == 'POST'){
 
 curl_setopt($curl, CURLOPT_RETURNTRANSFER,1);
 curl_setopt($curl, CURLOPT_TIMEOUT,30);
-curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 1);
+curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, 0);
 curl_setopt($curl, CURLOPT_COOKIEJAR, $cookie_file);
 curl_setopt($curl, CURLOPT_COOKIEFILE, $cookie_file);
 
@@ -104,7 +109,7 @@ if(curl_error($curl)){
 } else {
     list($response_headers, $response_body) = explode("\r\n\r\n", $response, 2);
 
-    $header_array = split(chr(10),$response_headers);
+    $header_array = preg_split('/\n/',$response_headers);
 	foreach($header_array as $header_name => $header_value){
         //handle headers - simply re-outputing them
         header(trim($header_value));
